==> kdepim4_4.14.10.orig.tar.xz: kdepim-4.14.10/pimcommon/gravatar/autotests/gravatardownloadpixmapdialogtest.cpp <==
/*
  Copyright (c) 2015 Montel Laurent <montel@kde.org>

  This program is free software; you can redistribute it and/or modify it
  under the terms of the GNU General Public License, version 2, as
  published by the Free Software Foundation.

  This program is distributed in the hope that it will be useful, but
  WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  General Public License for more details.

  You should have received a copy of the GNU General Public License along
  with this program; if not, write to the Free Software Foundation, Inc.,
  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
*/

#include "gravatardownloadpixmapdialogtest.h"
#include "../widgets/gravatardownloadpixmapdialog.h"

#include <QDialogButtonBox>
#include <qtest_kde.h>

#include "gravatar/widgets/gravatardownloadpixmapwidget.h"

GravatarDownloadPixmapDialogTest::GravatarDownloadPixmapDialogTest(QObject *parent)
    : QObject(parent)
{

}

GravatarDownloadPixmapDialogTest::~GravatarDownloadPixmapDialogTest()
{

}

void GravatarDownloadPixmapDialogTest::shouldHaveDefaultValue()
{
    PimCommon::GravatarDownloadPixmapDialog dlg;
    PimCommon::GravatarDownloadPixmapWidget *widget = qFindChild<PimCommon::GravatarDownloadPixmapWidget *>(&dlg, QLatin1String("gravatarwidget"));
    QVERIFY(widget);

    QDialogButtonBox *buttonBox = qFindChild<QDialogButtonBox *>(&dlg, QLatin1String("buttonbox"));
    QVERIFY(buttonBox);
}

QTEST_KDEMAIN(GravatarDownloadPixmapDialogTest, GUI)

==> kdepim-15.08.2.tar.xz: kdepim-15.08.2/pimcommon/gravatar/autotests/gravatardownloadpixmapdialogtest.cpp <==
/*
  Copyright (c) 2015 Montel Laurent <montel@kde.org>

  This program is free software; you can redistribute it and/or modify it
  under the terms of the GNU General Public License, version 2, as
  published by the Free Software Foundation.

  This program is distributed in the hope that it will be useful, but
  WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  General Public License for more details.

  You should have received a copy of the GNU General Public License along
  with this program; if not, write to the Free Software Foundation, Inc.,
  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
*/

#include "gravatardownloadpixmapdialogtest.h"
#include "../widgets/gravatardownloadpixmapdialog.h"

#include <QDialogButtonBox>
#include <qtest.h>
#include <QStandardPaths>
#include "gravatar/widgets/gravatardownloadpixmapwidget.h"

GravatarDownloadPixmapDialogTest::GravatarDownloadPixmapDialogTest(QObject *parent)
    : QObject(parent)
{

}

GravatarDownloadPixmapDialogTest::~GravatarDownloadPixmapDialogTest()
{

}

void GravatarDownloadPixmapDialogTest::initTestCase()
{
    QStandardPaths::setTestModeEnabled(true);
}

void GravatarDownloadPixmapDialogTest::shouldHaveDefaultValue()
{
    PimCommon::GravatarDownloadPixmapDialog dlg;
    PimCommon::GravatarDownloadPixmapWidget *widget = dlg.findChild<PimCommon::GravatarDownloadPixmapWidget *>(QStringLiteral("gravatarwidget"));
    QVERIFY(widget);

    QDialogButtonBox *buttonBox = dlg.findChild<QDialogButtonBox *>(QStringLiteral("buttonbox"));
    QVERIFY(buttonBox);
}

QTEST_MAIN(GravatarDownloadPixmapDialogTest)
